% pyfilemanager documentation master file, created by
% sphinx-quickstart on Tue Jan 23 10:31:39 2024.
% You can adapt this file completely to your liking, but it should at least
% contain the root `toctree` directive.

```{include} ../README.md
:relative-images:
```

```{toctree}
:hidden:
api
```
